.. _intro-install:

==================
Installation
==================

.. _faq-python-versions:

Supported Python versions
=========================

Python 3.6+


Installing pythonbible
=================

    pip install pythonbible
